from django.db import models
from django.utils.translation import gettext_lazy as _


class App(models.Model):
    api_id = models.CharField(max_length=255, verbose_name=_('API ID'))
    api_hash = models.CharField(max_length=255, verbose_name=_('API Hash'))

    class Meta:
        verbose_name = _('App')
        verbose_name_plural = _('Apps')



from django.db import models
from django.utils.translation import gettext_lazy as _


class LoginStatus(models.IntegerChoices):
    LOGIN_REQUIRED = 1
    LOGIN_DONE = 2
    LOGIN_FAILED = 3
    LOGIN_WAITING_FOR_TELEGRAM_CLIENT = 4

    @classmethod
    def approve(cls) -> list:
        return [cls.LOGIN_DONE.value, cls.LOGIN_WAITING_FOR_TELEGRAM_CLIENT.value]


class ClientSession(models.Model):
    name = models.CharField(
        max_length=255,
        verbose_name=_('Client Session Name'),
    )
    login_status = models.PositiveSmallIntegerField(
        default=LoginStatus.LOGIN_REQUIRED,
        choices=LoginStatus.choices,
        verbose_name=_('Login Required'),
    )

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Client Session')
        verbose_name_plural = _('Client Sessions')


class Session(models.Model):
    client_session = models.OneToOneField(
        'ClientSession',
        on_delete=models.CASCADE,
        primary_key=True,
        verbose_name=_('Client Session'),
    )
    auth_key = models.BinaryField(
        blank=False,
        null=False,
        editable=True,
        verbose_name=_('Auth Key'),
    )
    data_center_id = models.IntegerField(
        db_index=True,
        verbose_name=_('Data Center ID'),
    )
    port = models.IntegerField(
        verbose_name=_('Port'),
    )
    server_address = models.CharField(
        max_length=255,
        verbose_name=_('Server Address'),
    )
    takeout_id = models.BigIntegerField(
        null=True,
        verbose_name=_('Takeout ID'),
    )

    class Meta:
        unique_together = (
            (
                'client_session_id',
                'data_center_id',
            ),
        )
        verbose_name = _('Session')
        verbose_name_plural = _('Sessions')



from datetime import timedelta

from django.db import models
from django.db.models import Q
from django.utils.timezone import now
from django.utils.translation import gettext_lazy as _

from .sessions import LoginStatus


class LoginQueryset(models.QuerySet):
    def expired(self):
        return self.filter(
            Q(created_at__lt=now() - timedelta(minutes=5)) | Q(client_session__login_status__in=LoginStatus.approve())
        )

    def have_to_send_code(self):
        return self.filter(have_to_send_code=True).distinct('client_session')

    def have_to_login(self):
        return self.filter(code__isnull=False).distinct('client_session')


class LoginManager(models.Manager):
    def get_queryset(self):
        return LoginQueryset(self.model, using=self._db)

    def remove_old_logins(self):
        return self.all().expired().delete()


class Login(models.Model):
    client_session = models.ForeignKey('ClientSession', on_delete=models.CASCADE, verbose_name=_('Client session'))
    have_to_send_code = models.BooleanField(default=True, verbose_name=_('Have to send code'))
    bot_token = models.CharField(
        max_length=255,
        null=True,
        blank=True,
        verbose_name=_('Bot token'),
    )
    phone_number = models.CharField(
        max_length=20,
        null=True,
        blank=True,
        verbose_name=_('Phone number'),
    )
    code = models.CharField(
        max_length=10,
        null=True,
        blank=True,
        verbose_name=_('Code'),
    )
    passcode = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        verbose_name=_('Passcode'),
    )
    hash_code = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        verbose_name=_('Hash code'),
    )
    created_at = models.DateTimeField(
        auto_now_add=True,
        verbose_name=_('Created at'),
    )

    objects = LoginManager()

    class Meta:
        verbose_name = _('Login')
        verbose_name_plural = _('Logins')



import asyncio
import logging
import os

from django.core.management.base import BaseCommand

from django_telethon.utils import connect_clients, re_connect_clients


async def _entry_point():
    try:
        await connect_clients()
    except Exception as e:
        logging.exception(e, exc_info=True)

    while True:
        await asyncio.sleep(30)
        try:
            await re_connect_clients()
        except KeyboardInterrupt:
            break
        except Exception as e:
            logging.exception(e, exc_info=True)


class Command(BaseCommand):
    help = 'Run telegram'

    def handle(self, *args, **options):
        os.environ["DJANGO_ALLOW_ASYNC_UNSAFE"] = "true"
        asyncio.run(_entry_point())
        os.environ["DJANGO_ALLOW_ASYNC_UNSAFE"] = "false"
        self.stdout.write(self.style.SUCCESS('Successfully finished run telegram client'))



from django.db import models
from django.db.models import IntegerChoices
from django.utils.translation import gettext_lazy as _
from telethon.tl.types import InputDocument, InputPhoto


class SentFileType(IntegerChoices):
    DOCUMENT = 0
    PHOTO = 1

    @staticmethod
    def from_type(cls):
        if cls == InputDocument:
            return SentFileType.DOCUMENT
        elif cls == InputPhoto:
            return SentFileType.PHOTO
        else:
            raise ValueError('The cls must be either InputDocument/InputPhoto')


class SentFile(models.Model):
    client_session = models.ForeignKey(
        'ClientSession',
        on_delete=models.CASCADE,
        verbose_name=_('Client Session'),
    )
    md5_digest = models.BinaryField(
        verbose_name=_('MD5 digest'),
    )
    file_size = models.IntegerField(
        verbose_name=_('File size'),
    )
    file_type = models.IntegerField(
        choices=SentFileType.choices,
        verbose_name=_('Type'),
    )
    hash_value = models.BigIntegerField(
        verbose_name=_('Hash value'),
    )
    file_id = models.IntegerField(
        verbose_name=_('File ID'),
    )

    class Meta:
        unique_together = (
            (
                'client_session',
                'md5_digest',
                'file_size',
                'file_type',
            ),
        )
        verbose_name = _('Sent file')
        verbose_name_plural = _('Sent files')



from django.db import models
from django.utils.translation import gettext_lazy as _


class UpdateState(models.Model):
    """
    Model for storing the state of the update process.
    """

    client_session = models.ForeignKey(
        'ClientSession',
        on_delete=models.CASCADE,
        verbose_name=_('Client Session'),
    )
    pts = models.IntegerField(
        verbose_name=_('pts'),
    )
    qts = models.IntegerField(
        verbose_name=_('qts'),
    )
    date = models.DateTimeField(
        verbose_name=_('date'),
    )
    seq = models.IntegerField(
        verbose_name=_('seq'),
    )

    class Meta:
        verbose_name = _('Update state')
        verbose_name_plural = _('Update states')



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class DjangoTelethonConfig(AppConfig):
    name = 'django_telethon'
    verbose_name = _('Django Telethon')
    verbose_name_plural = _('Django Telethon')
    default_auto_field = 'django.db.models.BigAutoField'



from django.urls import path

from .apps import DjangoTelethonConfig
from .views import login_bot_view, login_user_view, send_code_request_view

app_name = DjangoTelethonConfig.name

_urlpatterns = [
    path('send-code-request/', send_code_request_view, name='send_code_request'),
    path('login-user-request/', login_user_view, name='login_user_request'),
    path('login-bot-request/', login_bot_view, name='login_bot_request'),
]


def django_telethon_urls():
    return _urlpatterns, app_name, app_name



import logging

from telethon import TelegramClient, events
from telethon.errors import SessionPasswordNeededError

from django_telethon.models import App, ClientSession, Login, LoginStatus
from django_telethon.sessions import DjangoSession


@events.register(events.NewMessage)
async def register_entity(event):
    # register entity
    await event.get_input_sender()


async def login_bot(client_session, bot_token):
    app = App.objects.first()
    if not app:
        raise ValueError("App does not exists.")
    telegram_client = TelegramClient(DjangoSession(client_session=client_session), app.api_id, app.api_hash)
    await telegram_client.connect()
    await telegram_client.sign_in(bot_token=bot_token)
    result = await telegram_client.is_user_authorized()
    await telegram_client.disconnect()
    return result


async def login_user(client_session, phone_number, code, password, phone_code_hash):
    app = App.objects.first()
    if not app:
        raise ValueError("App does not exists.")
    telegram_client = TelegramClient(DjangoSession(client_session=client_session), app.api_id, app.api_hash)
    await telegram_client.connect()
    try:
        await telegram_client.sign_in(phone=phone_number, code=code, phone_code_hash=phone_code_hash)
    except SessionPasswordNeededError:
        await telegram_client.sign_in(password=password)
    result = await telegram_client.is_user_authorized()
    await telegram_client.disconnect()
    return result


async def send_code_request(client_session, phone_number):
    app = App.objects.first()
    if not app:
        raise ValueError("App does not exists.")
    telegram_client = TelegramClient(DjangoSession(client_session=client_session), app.api_id, app.api_hash)
    await telegram_client.connect()
    result = await telegram_client.send_code_request(phone_number)
    await telegram_client.disconnect()
    return result.phone_code_hash


async def connect_client(client_app, app):
    telegram_client = TelegramClient(DjangoSession(client_session=client_app), app.api_id, app.api_hash)
    await telegram_client.connect()
    if not await telegram_client.is_user_authorized():
        client_app.login_status = LoginStatus.LOGIN_REQUIRED
        client_app.save()
        logging.critical(f"Authorization failed for client: {client_app.name}")
        return
    if client_app.login_status != LoginStatus.LOGIN_DONE:
        client_app.login_status = LoginStatus.LOGIN_DONE
        client_app.save()

    await telegram_client.start()
    telegram_client.add_event_handler(register_entity)


async def connect_clients():
    app = App.objects.first()
    if not app:
        logging.debug("App does not exists.")
        return

    for client in ClientSession.objects.filter(login_status__in=LoginStatus.approve()):
        await connect_client(client, app)


async def re_connect_clients():
    app = App.objects.first()
    if not app:
        logging.debug("App does not exists.")
        return
    Login.objects.remove_old_logins()
    # sends code
    for login in Login.objects.all().have_to_send_code():
        phone_hash = await send_code_request(login.client_session, login.phone_number)
        login.hash_code = phone_hash
        login.have_to_send_code = False
        login.save()
    # logs in
    for login in Login.objects.all().have_to_login():
        if login.bot_token:
            login_result = await login_bot(login.client_session, login.bot_token)
        else:
            login_result = await login_user(
                login.client_session, login.phone_number, login.code, login.passcode, login.hash_code
            )
        if login_result:
            login.client_session.login_status = LoginStatus.LOGIN_WAITING_FOR_TELEGRAM_CLIENT
            login.client_session.save()
            logging.debug(f"Login successfully for client: {login.client_session.name}")
        else:
            logging.debug(f"Login failed for client: {login.client_session.name}")
        login.delete()
    for client in ClientSession.objects.filter(login_status=LoginStatus.LOGIN_WAITING_FOR_TELEGRAM_CLIENT):
        await connect_client(client, app)



from django.db import models
from django.utils.translation import gettext_lazy as _


class Entity(models.Model):
    client_session = models.ForeignKey(
        'ClientSession',
        on_delete=models.SET_NULL,
        null=True,
        verbose_name=_('Client Session'),
    )
    hash_value = models.BigIntegerField(
        blank=False,
        null=False,
        verbose_name=_('Hash Value'),
    )
    username = models.CharField(
        max_length=255,
        blank=True,
        null=True,
        verbose_name=_('Username'),
    )
    phone = models.CharField(
        max_length=15,
        blank=True,
        null=True,
        verbose_name=_('Phone'),
    )
    name = models.CharField(
        max_length=50,
        blank=True,
        null=True,
        verbose_name=_('Name'),
    )
    date = models.DateTimeField(
        auto_now_add=True,
        verbose_name=_('Date'),
    )

    class Meta:
        verbose_name = _('Entity')
        verbose_name_plural = _('Entities')



from .apps import App  # noqa
from .entities import Entity  # noqa
from .login import Login  # noqa
from .sentfiles import SentFile  # noqa
from .sessions import ClientSession, LoginStatus, Session  # noqa
from .states import UpdateState  # noqa



import json

from django.core.exceptions import ObjectDoesNotExist
from django.http import JsonResponse

from django_telethon.models import App, ClientSession, Login, LoginStatus


def _get_data(request):
    if 'application/json' in request.META.get('CONTENT_TYPE', ''):
        data = request.body.decode('utf-8')
        data = json.loads(data)
    else:
        data = request.POST
    return data


def send_code_request_view(request):
    data = _get_data(request)
    phone_number = data.get('phone_number', None)
    client_session_name = data.get('client_session_name', None)
    if not App.objects.all().exists():
        return JsonResponse({'error': 'No app found'}, status=400)

    if not phone_number or not client_session_name:
        return JsonResponse({'error': 'Missing phone number or client session name'}, status=400)
    client_session, is_created = ClientSession.objects.get_or_create(name=client_session_name)

    if client_session.login_status != LoginStatus.LOGIN_REQUIRED:
        return JsonResponse({'error': 'Client session is not in login required status'}, status=400)

    if Login.objects.filter(client_session=client_session).have_to_send_code().exists():
        return JsonResponse({'error': 'Client session is already waiting for send code.'}, status=400)

    login = Login.objects.create(client_session=client_session, phone_number=phone_number, have_to_send_code=True)
    return JsonResponse({'login_id': login.id}, status=200)


def login_user_view(request):
    data = _get_data(request)
    client_session_name = data.get('client_session_name', None)
    phone_number = data.get('phone_number', None)
    code = data.get('code', None)
    password = data.get('password', None)

    if not App.objects.all().exists():
        return JsonResponse({'error': 'No app found'}, status=400)

    if not phone_number or not client_session_name or not code:
        return JsonResponse({'error': 'Missing phone number or client session name or code'}, status=400)
    try:
        client_session = ClientSession.objects.get(name=client_session_name)
    except ObjectDoesNotExist:
        return JsonResponse({'error': 'Client session does not exists'}, status=400)

    if client_session.login_status != LoginStatus.LOGIN_REQUIRED:
        return JsonResponse({'error': 'Client session is not in login required status'}, status=400)

    if not password:
        password = None
    if (
        login := Login.objects.filter(have_to_send_code=False, client_session=client_session)
        .order_by('-created_at')
        .first()
    ):
        login.code = code
        login.passcode = password
        login.save()
    return JsonResponse({}, status=200)


def login_bot_view(request):
    data = _get_data(request)
    client_session_name = data.get('client_session_name', None)
    bot_token = data.get('bot_token', None)

    if not App.objects.all().exists():
        return JsonResponse({'error': 'No app found'}, status=400)

    if not bot_token or not client_session_name:
        return JsonResponse({'error': 'Missing bot token or client session name or code'}, status=400)

    client_session = ClientSession.objects.get_or_create(name=client_session_name)

    if client_session.login_status != LoginStatus.LOGIN_REQUIRED:
        return JsonResponse({'error': 'Client session is not in login required status'}, status=400)

    login = Login.objects.create(client_session=client_session, bot_token=bot_token, have_to_send_code=False)
    return JsonResponse({'login_id': login.id}, status=200)



import logging

from django.core.exceptions import ObjectDoesNotExist
from telethon import utils
from telethon.crypto import AuthKey
from telethon.sessions import MemorySession
from telethon.tl import types
from telethon.tl.types import InputDocument, InputPhoto, PeerChannel, PeerChat, PeerUser

from .models import ClientSession, Entity, Session, UpdateState
from .models.sentfiles import SentFileType

"""
Read the following carefully before changing anything in this file.
https://github.com/LonamiWebs/Telethon/blob/master/telethon/sessions.py
"""


class DjangoSession(MemorySession):
    """This session contains the required information to login into your
    Telegram account. NEVER give the saved session file to anyone, since
    they would gain instant access to all your messages and contacts.

    If you think the session has been compromised, close all the sessions
    through an official Telegram client to revoke the authorization.
    """

    def __init__(self, client_session: ClientSession, *args, **kwargs):
        self.save_entities = True
        super().__init__()
        self.client_session = client_session
        if hasattr(self.client_session, 'session'):
            session = self.client_session.session
            self._dc_id = session.data_center_id
            self._server_address = session.server_address
            self._port = session.port
            self._takeout_id = session.takeout_id
            auth_key = session.auth_key
            if isinstance(auth_key, memoryview):
                auth_key = auth_key.tobytes()
            self._auth_key = AuthKey(data=auth_key)
        else:
            self._auth_key = None

    def clone(self, to_instance=None):
        cloned = super().clone(to_instance)
        cloned.save_entities = self.save_entities
        return cloned

    # Data from sessions should be kept as properties
    # not to fetch the database every time we need it
    def set_dc(self, dc_id, server_address, port):
        super().set_dc(dc_id, server_address, port)
        self._update_session_table()
        # Fetch the auth_key corresponding to this data center
        try:
            session = Session.objects.get(client_session=self.client_session)
            auth_key = session.auth_key
            if isinstance(auth_key, memoryview):
                auth_key = auth_key.tobytes()
        except ObjectDoesNotExist:
            auth_key = None
        self._auth_key = AuthKey(data=auth_key) if auth_key else None

    @MemorySession.auth_key.setter
    def auth_key(self, value):
        if value == self._auth_key:
            return
        self._auth_key = value
        self._update_session_table()

    @MemorySession.takeout_id.setter
    def takeout_id(self, value):
        self._takeout_id = value
        if value == self._takeout_id:
            return
        self._update_session_table()

    def _update_session_table(self):
        # While we can save multiple rows into the sessions table
        # currently we only want to keep ONE as the tables don't
        # tell us which auth_key's are usable and will work. Needs
        # some more work before being able to save auth_key's for
        # multiple DCs. Probably done differently.
        defaults = {
            'data_center_id': self._dc_id,
            'server_address': self._server_address,
            'port': self._port,
            'auth_key': self._auth_key.key if self._auth_key else b'',
            'takeout_id': self._takeout_id,
        }
        Session.objects.update_or_create(
            client_session=self.client_session,
            defaults=defaults,
        )

    def get_update_state(self, entity_id):
        try:
            state = self.client_session.updatestate_set.get(pk=entity_id)
            return types.updates.State(state.pts, state.qts, state.date, state.seq, unread_count=0)
        except UpdateState.DoesNotExist:
            return None

    def set_update_state(self, entity_id, state):
        self.client_session.updatestate_set.update_or_create(
            pk=entity_id,
            defaults={
                'pts': state.pts,
                'qts': state.qts,
                'date': state.date,
                'seq': state.seq,
            },
        )

    def save(self):
        """Saves the current session object as session_user_id.session"""
        # This is a no-op if there are no changes to commit, so there's
        # no need for us to keep track of an "unsaved changes" variable.
        pass

    def delete(self):

        """Deletes the current session file"""
        try:
            self.client_session.delete()
            return True
        except Exception:
            logging.exception('Failed to delete session')
            return False

    @classmethod
    def list_sessions(cls):

        """Lists all the sessions of the users who have ever connected
        using this client and never logged out
        """
        return ClientSession.objects.all().values_list('name', flat=True)

    # Entity processing

    def process_entities(self, tlo):
        """
        Processes all the found entities on the given TLObject,
        unless .save_entities is False.
        """
        self._process_entities(tlo)

    def _process_entities(self, tlo):
        if not self.save_entities:
            return

        rows = self._entities_to_rows(tlo)
        if not rows:
            return

        entities = self.client_session.entity_set.filter(pk__in=[row[0] for row in rows])
        entities_does_not_exists = []
        for row in rows:
            is_find = False
            for entity in entities:
                if entity.pk == row[0]:
                    is_find = True
                    entity.hash_value = row[1]
                    entity.username = row[2]
                    entity.phone = row[3]
                    entity.name = row[4]
            if not is_find:
                entities_does_not_exists.append(
                    Entity(
                        pk=row[0],
                        client_session=self.client_session,
                        hash_value=row[1],
                        username=row[2],
                        phone=row[3],
                        name=row[4],
                    )
                )
        self.client_session.entity_set.bulk_update(entities, ['hash_value', 'username', 'phone', 'name'])
        self.client_session.entity_set.bulk_create(entities_does_not_exists)

    def get_entity_rows_by_phone(self, phone):

        return self.client_session.entity_set.filter(phone=phone).values_list('pk', 'hash_value').first()

    def get_entity_rows_by_username(self, username):

        queryset = list(self.client_session.entity_set.filter(username=username).order_by('-date'))
        if len(queryset) > 1:
            # If there is more than one result for the same username, evict the oldest one
            logging.warning('Found more than one entity with username %s', username)
            self.client_session.entity_set.filter(pk__in=[obj.pk for obj in queryset[1:]]).update(username=None)
        if not queryset:
            return None
        return queryset[0].pk, queryset[0].hash_value

    def get_entity_rows_by_name(self, name):

        return self.client_session.entity_set.filter(name=name).values_list('pk', 'hash_value').first()

    def get_entity_rows_by_id(self, id, exact=True):

        if exact:
            return self.client_session.entity_set.filter(pk=id).values_list('pk', 'hash_value').first()
        else:
            return (
                self.client_session.entity_set.filter(
                    pk__in=[
                        utils.get_peer_id(PeerUser(id)),
                        utils.get_peer_id(PeerChat(id)),
                        utils.get_peer_id(PeerChannel(id)),
                    ]
                )
                .values_list('pk', 'hash_value')
                .first()
            )

    # File processing

    def get_file(self, md5_digest, file_size, cls):

        if (
            row := self.client_session.sentfile_set.filter(
                md5_digest=md5_digest, file_size=file_size, file_type=SentFileType.from_type(cls).value
            )
            .values_list('pk', 'hash_value')
            .first()
        ):
            # Both allowed classes have (id, access_hash) as parameters
            return cls(row[0], row[1])

    def cache_file(self, md5_digest, file_size, instance):

        if not isinstance(instance, (InputDocument, InputPhoto)):
            raise TypeError(f'Cannot cache {type(instance)} instance')
        self.client_session.sentfile_set.update_or_create(
            md5_digest=md5_digest,
            file_size=file_size,
            file_type=SentFileType.from_type(type(instance)).value,
            defaults={'hash_value': instance.access_hash, 'file_id': instance.id},
        )



import os

from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md'), encoding="utf-8") as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-telethon',
    version='1.1.0',
    packages=find_packages(),
    include_package_data=True,
    license='BSD License',
    description='Telethon for django',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/ali-zahedi/django-telethon',
    author='Ali Zahedigol',
    author_email='alizahedigol@gmail.com',
    python_requires='>=3.7',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 3.0',
        'Framework :: Django :: 3.1',
        'Framework :: Django :: 3.2',
        'Framework :: Django :: 4.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=[
        'Django>=3.0',
        'Telethon>=1.24.0,<2',
    ],
    extras_require={
        'dev': [
            'flake8',
            'black',
            'isort',
            'pre-commit',
            'whitenoise',
        ]
    },
)



# Generated by Django 4.0.3 on 2022-07-17 01:03

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name='App',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('api_id', models.CharField(max_length=255, verbose_name='API ID')),
                ('api_hash', models.CharField(max_length=255, verbose_name='API Hash')),
            ],
            options={
                'verbose_name': 'App',
                'verbose_name_plural': 'Apps',
            },
        ),
        migrations.CreateModel(
            name='ClientSession',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Client Session Name')),
                (
                    'login_status',
                    models.PositiveSmallIntegerField(
                        choices=[
                            (1, 'Login Required'),
                            (2, 'Login Done'),
                            (3, 'Login Failed'),
                            (4, 'Login Waiting For Telegram Client'),
                        ],
                        default=1,
                        verbose_name='Login Required',
                    ),
                ),
            ],
            options={
                'verbose_name': 'Client Session',
                'verbose_name_plural': 'Client Sessions',
            },
        ),
        migrations.CreateModel(
            name='UpdateState',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pts', models.IntegerField(verbose_name='pts')),
                ('qts', models.IntegerField(verbose_name='qts')),
                ('date', models.DateTimeField(verbose_name='date')),
                ('seq', models.IntegerField(verbose_name='seq')),
                (
                    'client_session',
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to='django_telethon.clientsession',
                        verbose_name='Client Session',
                    ),
                ),
            ],
            options={
                'verbose_name': 'Update state',
                'verbose_name_plural': 'Update states',
            },
        ),
        migrations.CreateModel(
            name='Login',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('have_to_send_code', models.BooleanField(default=True, verbose_name='Have to send code')),
                ('bot_token', models.CharField(blank=True, max_length=255, null=True, verbose_name='Bot token')),
                ('phone_number', models.CharField(blank=True, max_length=20, null=True, verbose_name='Phone number')),
                ('code', models.CharField(blank=True, max_length=10, null=True, verbose_name='Code')),
                ('passcode', models.CharField(blank=True, max_length=100, null=True, verbose_name='Passcode')),
                ('hash_code', models.CharField(blank=True, max_length=100, null=True, verbose_name='Hash code')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                (
                    'client_session',
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to='django_telethon.clientsession',
                        verbose_name='Client session',
                    ),
                ),
            ],
            options={
                'verbose_name': 'Login',
                'verbose_name_plural': 'Logins',
            },
        ),
        migrations.CreateModel(
            name='Entity',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('hash_value', models.BigIntegerField(verbose_name='Hash Value')),
                ('username', models.CharField(blank=True, max_length=255, null=True, verbose_name='Username')),
                ('phone', models.CharField(blank=True, max_length=15, null=True, verbose_name='Phone')),
                ('name', models.CharField(blank=True, max_length=50, null=True, verbose_name='Name')),
                ('date', models.DateTimeField(auto_now_add=True, verbose_name='Date')),
                (
                    'client_session',
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to='django_telethon.clientsession',
                        verbose_name='Client Session',
                    ),
                ),
            ],
            options={
                'verbose_name': 'Entity',
                'verbose_name_plural': 'Entities',
            },
        ),
        migrations.CreateModel(
            name='Session',
            fields=[
                (
                    'client_session',
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        primary_key=True,
                        serialize=False,
                        to='django_telethon.clientsession',
                        verbose_name='Client Session',
                    ),
                ),
                ('auth_key', models.BinaryField(editable=True, verbose_name='Auth Key')),
                ('data_center_id', models.IntegerField(db_index=True, verbose_name='Data Center ID')),
                ('port', models.IntegerField(verbose_name='Port')),
                ('server_address', models.CharField(max_length=255, verbose_name='Server Address')),
                ('takeout_id', models.BigIntegerField(null=True, verbose_name='Takeout ID')),
            ],
            options={
                'verbose_name': 'Session',
                'verbose_name_plural': 'Sessions',
                'unique_together': {('client_session_id', 'data_center_id')},
            },
        ),
        migrations.CreateModel(
            name='SentFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('md5_digest', models.BinaryField(verbose_name='MD5 digest')),
                ('file_size', models.IntegerField(verbose_name='File size')),
                ('file_type', models.IntegerField(choices=[(0, 'Document'), (1, 'Photo')], verbose_name='Type')),
                ('hash_value', models.BigIntegerField(verbose_name='Hash value')),
                ('file_id', models.IntegerField(verbose_name='File ID')),
                (
                    'client_session',
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to='django_telethon.clientsession',
                        verbose_name='Client Session',
                    ),
                ),
            ],
            options={
                'verbose_name': 'Sent file',
                'verbose_name_plural': 'Sent files',
                'unique_together': {('client_session', 'md5_digest', 'file_size', 'file_type')},
            },
        ),
    ]



from django.contrib import admin

from .models import App, ClientSession, Entity, Login, SentFile, Session, UpdateState


class AppAdmin(admin.ModelAdmin):
    list_display = (
        'api_id',
        'api_hash',
    )


class ClientSessionAdmin(admin.ModelAdmin):
    list_display = ['id', 'name', 'login_status']
    list_filter = ('login_status',)


class LoginAdmin(admin.ModelAdmin):
    list_display = [
        'id',
        'client_session',
        'have_to_send_code',
        'bot_token',
        'phone_number',
        'code',
        'passcode',
        'hash_code',
        'created_at',
    ]
    list_filter = ['created_at', 'client_session__name']


class SessionAdmin(admin.ModelAdmin):
    list_display = [
        'client_session',
        'auth_key',
        'data_center_id',
        'port',
        'server_address',
        'takeout_id',
    ]
    raw_id_fields = ['client_session']
    list_filter = ['client_session__name']


class EntityAdmin(admin.ModelAdmin):
    list_display = [
        'id',
        'client_session',
        'hash_value',
        'username',
        'phone',
        'name',
        'date',
    ]
    raw_id_fields = ['client_session']
    list_filter = ['client_session__name']


class UpdateStateAdmin(admin.ModelAdmin):
    list_display = [
        'id',
        'client_session',
        'pts',
        'qts',
        'date',
        'seq',
    ]
    raw_id_fields = ['client_session']
    list_filter = ['client_session__name']


class SentFileAdmin(admin.ModelAdmin):
    list_display = [
        'id',
        'client_session',
        'md5_digest',
        'file_size',
        'file_type',
        'hash_value',
        'file_id',
    ]
    raw_id_fields = ['client_session']
    list_filter = ['client_session__name']


admin.site.register(App, AppAdmin)
admin.site.register(ClientSession, ClientSessionAdmin)
admin.site.register(Login, LoginAdmin)
admin.site.register(Session, SessionAdmin)
admin.site.register(Entity, EntityAdmin)
admin.site.register(UpdateState, UpdateStateAdmin)
admin.site.register(SentFile, SentFileAdmin)
